Module ast

Module ast 

Structs

PathStep
A step in a path expression with optional stages

Enums

AstNode
AST Node types
BinaryOp
Binary operators
Stage
Stage types that can be attached to path steps
UnaryOp
Unary operators