pub fn length(s: &str) -> Result<JValue, FunctionError>Expand description
$length() - Get string length with proper Unicode support Returns the number of Unicode characters (not bytes)
pub fn length(s: &str) -> Result<JValue, FunctionError>$length() - Get string length with proper Unicode support Returns the number of Unicode characters (not bytes)