trim

Function trim 

pub fn trim(s: &str) -> Result<JValue, FunctionError>
$trim(str) - Normalize and trim whitespace

Normalizes whitespace by replacing runs of whitespace characters (space, tab, newline, etc.) with a single space, then strips leading and trailing spaces.