Skip to main content Module string Copy item path Source build_regex Helper to build a Regex from pattern and flags contains $contains(str, pattern) - Check if string contains substring or matches regex extract_regex Helper to detect and extract regex from a JValue join $join(array, separator) - Join array into string length $length() - Get string length with proper Unicode support
Returns the number of Unicode characters (not bytes) lowercase $lowercase() - Convert to lowercase replace $replace(str, pattern, replacement, limit) - Replace substring or regex matches split $split(str, separator, limit) - Split string into array
separator can be a string or a regex object string $string(value, prettify) - Convert value to string substring $substring(str, start, length) - Extract substring
Extracts a substring from a string using Unicode character positions.
Follows the JSONata spec (which mirrors JS Array.prototype.slice): substring_after $substringAfter(str, separator) - Get substring after separator substring_before $substringBefore(str, separator) - Get substring before separator trim $trim(str) - Normalize and trim whitespace uppercase $uppercase() - Convert to uppercase